Skip to contents

Posterior mean values from mixglm

Usage

# S3 method for class 'mixglm'
coef(object, digit = NULL, ...)

Arguments

object

an object of class "mixglm"

digit

integer specifying the number of decimal places to be used. Use "NULL" for no rounding.

...

further arguments passed to or from other methods.

Value

A List of matrices of posterior mean values for each parameter

Author

Adam Klimes