Skip to contents

Calculate the probability density of a response variable from beta mixture.

Usage

dbetaStateValueMembership(x, stateVal, statePrec, stateProb, log = 0)

Arguments

x

A scalar value containing the value of the response variable

stateVal

A numeric vector containing the mean values of the mixture components

statePrec

A numeric vector containing the precision (reciprocal of the variance) of the mixture components

stateProb

A numeric vector containing the probabilities of belonging to each mixture component (internally normalised to one)

log

If TRUE then return the log density

Value

A scalar containing the probability density

Author

Joseph D. Chipperfield, joechip90@googlemail.com