Probability Density of a response variable from gamma mixture (Gamma Error)
dgammaStateValueMembership.RdCalculate the probability density of a response variable from gamma mixture.
Arguments
- x
A scalar value containing the value of response variable
- stateVal
A numeric vector containing the mean values of mixture components
- statePrec
A numeric vector containing the precision (reciprocal of the variance) of the mixture components
- stateProb
A numeric vector containing the probabilities of belonging to each mixture component (internally normalised to one)
- log
If
TRUEthen return the log density
Author
Joseph D. Chipperfield, joechip90@googlemail.com