Skip to contents

Compactly display the internal structure of a mixglm object

Usage

# S3 method for class 'mixglm'
str(object, max.level = 2, give.attr = FALSE, ...)

Arguments

object

an object of class "mixglm"

max.level

integer giving maximal level of nesting of displayed structures

give.attr

logical indicating if attributes should be shown

...

arguments passed to NextMethod

Author

Adam Klimes